@@ -35,7 +35,7 @@
 /* #undef WITH_MACAUDIO */
 /* #undef WITH_OSS */
 #define WITH_ALSA
-/* #undef WITH_PULSE */
+#define WITH_PULSE
 /* #undef WITH_IOSAUDIO */
 /* #undef WITH_OPENSLES */
 /* #undef WITH_GSM */
