@@ -1,7 +1,7 @@
 #ifndef WINPR_BUILD_FLAGS_H
 #define WINPR_BUILD_FLAGS_H
 
-#define WINPR_CFLAGS "-O2 -pipe -march=x86-64 -mtune=generic -Werror=odr -Werror=lto-type-mismatch -Werror=strict-aliasing -fvisibility=hidden -fno-omit-frame-pointer -Wredundant-decls -Wimplicit-function-declaration -fvisibility=hidden "
+#define WINPR_CFLAGS "-O2 -pipe -march=x86-64-v3 -Werror=odr -Werror=lto-type-mismatch -Werror=strict-aliasing -fvisibility=hidden -fno-omit-frame-pointer -Wredundant-decls -Wimplicit-function-declaration -fvisibility=hidden "
 #define WINPR_COMPILER_ID "GNU"
 #define WINPR_COMPILER_VERSION "14.3.1"
 #define WINPR_TARGET_ARCH "x64"
